==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/screenshot/translations/screenshot_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Vyberte obrázkový formát, v němž budou snímky obrazovky ukládány a posílány.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Vynutit příponu .jpg pro formát JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Vynutí užití krátké přípony .jpg pro soubory ve formátu JPEG. Některé další programy pro okamžitou výměnu zpráv to potřebují.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Jakost snímků obrazovky</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 pro automatické určení, 0 pro nejlepší zhuštění, 100 pro nejlepší jakost obrázku.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Adresář</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Cesta k adresáři se snímky obrazovky</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Souborová předpona snímků obrazovky</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Povolit ovládání velikosti adresáře</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Největší velikost adresáře</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Omezení velikosti obrázku se snímkem obrazovky</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Navíc</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Souborový formát snímku obrazovky</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Vložit obrázek do okna pro rozhovor automaticky</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Je-li povoleno, přídavný modul do okna pro rozhovor automaticky vloží doložku [OBRÁZEK] připraven k poslání.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Je-li povoleno, přídavný modul přezkouší velikost adresáře se snímky obrazovky a bude vás varovat, pokud bude mít velikost stanovenou níže.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Stanovte, kolik kB může v adresáři být obsazeno snímky obrazovky, předtím než vás přídavný modul bude varovat.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Velikost obrázku je větší než největší velikost obrázku pro tento rozhovor.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Nelze vytvořit adresář %1 pro ukládání snímků obrazovky!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Nelze zapsat soubor %1.
Přístup odepřen, nebo jde o jiné potíže!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Snímek obrazovky %1 má nulovou velikost!
Měl by být větší.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>Simple Shot</source>
        <translation>Jednoduchý snímek</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>S oknem pro rozhovor skrytým</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Snímek okna</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Omezení velikosti snímku obrazovky</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Omezení velikosti snímku obrazovky překročeno: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Přetáhněte tuto ikonu do požadovaného okna</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Snímek okna</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Oříznout</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/screenshot/translations/screenshot_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Snímek obrazovky</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Vyberte obrázkový formát, v němž budou snímky obrazovky ukládány a posílány.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Vynutit příponu .jpg pro formát JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Vynutí užití krátké přípony .jpg pro soubory ve formátu JPEG. Některé další programy pro okamžitou výměnu zpráv to potřebují.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Jakost snímků obrazovky</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 pro automatické určení, 0 pro nejlepší zhuštění, 100 pro nejlepší jakost obrázku.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Adresář</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Cesta k adresáři se snímky obrazovky</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Souborová předpona snímků obrazovky</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Povolit ovládání velikosti adresáře</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Největší velikost adresáře</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Omezení velikosti obrázku se snímkem obrazovky</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Navíc</translation>
    </message>
    <message>
        <source>Screenshot file format</source>
        <translation>Souborový formát snímku obrazovky</translation>
    </message>
    <message>
        <source>Paste image to chat window automatically</source>
        <translation>Vložit obrázek do okna pro rozhovor automaticky</translation>
    </message>
    <message>
        <source>When enabled, plugin will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Je-li povoleno, přídavný modul do okna pro rozhovor automaticky vloží doložku [OBRÁZEK] připraven k poslání.</translation>
    </message>
    <message>
        <source>When enabled, plugin will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Je-li povoleno, přídavný modul přezkouší velikost adresáře se snímky obrazovky a bude vás varovat, pokud bude mít velikost stanovenou níže.</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before plugin will warn you.</source>
        <translation>Stanovte, kolik kB může v adresáři být obsazeno snímky obrazovky, předtím než vás přídavný modul bude varovat.</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Velikost obrázku je větší než největší velikost obrázku pro tento rozhovor.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Nelze vytvořit adresář %1 pro ukládání snímků obrazovky!</translation>
    </message>
    <message>
        <source>Can't write file %1.
Access denied or other problem!</source>
        <translation>Nelze zapsat soubor %1.
Přístup odepřen, nebo jde o jiné potíže!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Snímek obrazovky %1 má nulovou velikost!
Měl by být větší.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>Simple Shot</source>
        <translation>Jednoduchý snímek</translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation>S oknem pro rozhovor skrytým</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Snímek okna</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotificationService</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Omezení velikosti snímku obrazovky</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Omezení velikosti snímku obrazovky překročeno: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation>Přetáhněte tuto ikonu do požadovaného okna</translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation>Snímek okna</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Oříznout</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
</TS>
